import { Collection } from './Util';
import { Container } from './Container';
import { SceneCanvas, HitCanvas } from './Canvas';
import { GetSet, Vector2d } from './types';
import { Shape } from './Shape';
import { BaseLayer } from './BaseLayer';
export declare const stages: Stage[];
/**
 * Stage constructor.  A stage is used to contain multiple layers
 * @constructor
 * @memberof Konva
 * @augments Konva.Container
 * @param {Object} config
 * @param {String|Element} config.container Container selector or DOM element
 * @@nodeParams
 * @example
 * var stage = new Konva.Stage({
 *   width: 500,
 *   height: 800,
 *   container: 'containerId' // or "#containerId" or ".containerClass"
 * });
 */
export declare class Stage extends Container {
    content: HTMLDivElement;
    pointerPos: Vector2d | null;
    bufferCanvas: SceneCanvas;
    bufferHitCanvas: HitCanvas;
    targetShape: Shape;
    clickStartShape: Shape;
    clickEndShape: Shape;
    dblTimeout: any;
    tapStartShape: Shape;
    children: Collection<BaseLayer>;
    constructor(config: any);
    _validateAdd(child: any): void;
    /**
     * set container dom element which contains the stage wrapper div element
     * @method
     * @name Konva.Stage#setContainer
     * @param {DomElement} container can pass in a dom element or id string
     */
    setContainer(container: any): this;
    shouldDrawHit(): boolean;
    /**
     * clear all layers
     * @method
     * @name Konva.Stage#clear
     */
    clear(): this;
    clone(obj: any): any;
    destroy(): this;
    /**
     * get pointer position which can be a touch position or mouse position
     * @method
     * @name Konva.Stage#getPointerPosition
     * @returns {Object}
     */
    getPointerPosition(): Vector2d;
    getStage(): this;
    getContent(): HTMLDivElement;
    _toKonvaCanvas(config: any): SceneCanvas;
    /**
     * get visible intersection shape. This is the preferred
     *  method for determining if a point intersects a shape or not
     * @method
     * @name Konva.Stage#getIntersection
     * @param {Object} pos
     * @param {Number} pos.x
     * @param {Number} pos.y
     * @param {String} [selector]
     * @returns {Konva.Node}
     * @example
     * var shape = stage.getIntersection({x: 50, y: 50});
     * // or if you interested in shape parent:
     * var group = stage.getIntersection({x: 50, y: 50}, 'Group');
     */
    getIntersection(pos: Vector2d, selector?: string): any;
    _resizeDOM(): void;
    add(layer: any): this;
    getParent(): any;
    getLayer(): any;
    /**
     * returns a {@link Konva.Collection} of layers
     * @method
     * @name Konva.Stage#getLayers
     */
    getLayers(): Collection<import("./Node").Node>;
    _bindContentEvents(): void;
    _mouseover(evt: any): void;
    _mouseout(evt: any): void;
    _mousemove(evt: any): void;
    _mousedown(evt: any): void;
    _mouseup(evt: any): void;
    _contextmenu(evt: any): void;
    _touchstart(evt: any): void;
    _touchend(evt: any): void;
    _touchmove(evt: any): void;
    _wheel(evt: any): void;
    _setPointerPosition(evt: any): void;
    _getContentPosition(): {
        top: number;
        left: number;
    };
    _buildDOM(): void;
    _onContent(typesStr: any, handler: any): void;
    cache(): this;
    clearCache(): this;
    container: GetSet<HTMLDivElement, this>;
    batchDraw: () => void;
}
/**
 * get/set container DOM element
 * @method
 * @name Konva.Stage#container
 * @returns {DomElement} container
 * @example
 * // get container
 * var container = stage.container();
 * // set container
 * var container = document.createElement('div');
 * body.appendChild(container);
 * stage.container(container);
 */
